@@ -9,6 +9,9 @@ from numba import jit
 from . import parallel
 
 
+arpack_tol = 1e-5
+arpack_maxiter = 10000
+
 
 
 import numbers
@@ -85,38 +88,45 @@ def braket_ww(w,wi):
 
 
 def disentangle_manifold(wfs,A):
-  """
-  Disentangles the wavefunctions of a degenerate manifold
-  by expressing them in terms of eigenvalues of an input operator
-  """
-  ma = get_representation(wfs,A) # get the matrix form of the operator
-  wfsout = [] # empty list
-  evals,evecs = dlg.eigh(ma) # diagonalize
-
-  evecs = evecs.transpose() # transpose eigenvectors
-  for v in evecs: # loop over eigenvectors
-    wf = wfs[0]*0.0j
-    for (i,iv) in zip(range(len(v)),v): # loop over components
-      wf += iv*wfs[i] # add contribution
-    wfsout.append(wf.copy()) # store wavefunction
-  return wfsout
+    """
+    Disentangles the wavefunctions of a degenerate manifold
+    by expressing them in terms of eigenvalues of an input operator
+    """
+    ma = get_representation(wfs,A) # get the matrix form of the operator
+    wfsout = [] # empty list
+    evals,evecs = dlg.eigh(ma) # diagonalize
+    evecs = np.conjugate(evecs.T) # transpose eigenvectors
+#    print("Representation")
+#    print(np.round(ma,2))
+#    print("Eigenvectors")
+#    print(np.round(evecs,2))
+    for v in evecs: # loop over eigenvectors
+      wf = wfs[0]*0.0j
+      for (i,iv) in zip(range(len(v)),v): # loop over components
+        wf = wf + iv*wfs[i] # add contribution
+      wfsout.append(wf.copy()) # store wavefunction
+    return wfsout
 
 
 
 def get_representation(wfs,A):
-  """
-  Gets the matrix representation of a certain operator
-  """
-  n = len(wfs) # number of eigenfunctions
-  ma = np.zeros((n,n),dtype=np.complex) # representation of A
-  sa = csc(A) # sparse matrix
-  for i in range(n):
-    vi = csc(np.conjugate(wfs[i])) # first wavefunction
-    for j in range(n):
-      vj = csc(wfs[j]).transpose() # second wavefunction
-      data = (vi*sa*vj).todense()[0,0]
-      ma[i,j] = data
-  return ma
+    """
+    Gets the matrix representation of a certain operator
+    """
+    n = len(wfs) # number of eigenfunctions
+    ma = np.zeros((n,n),dtype=np.complex) # representation of A
+    A = np.array(A)
+    for i in range(n):
+      vi = wfs[i] # first wavefunction
+      for j in range(n):
+        vj = np.conjugate(wfs[j]) # first wavefunction
+        data = vi@A@vj
+        ma[i,j] = data
+#    if len(ma)==2:
+#      print("Representation")
+#      print(np.round(ma,2))
+#      print(dlg.eigvalsh(ma))
+    return ma
 
 
 
@@ -210,7 +220,7 @@ def matrix2vector(v):
 
 
 
-def smalleig(m,numw=10,evecs=False,tol=1e-7):
+def smalleig(m,numw=10,evecs=False,tol=arpack_tol):
     """
     Return the smallest eigenvalues using arpack
     """
