@@ -77,6 +77,8 @@ class Hamiltonian():
     def add_strain(self,fs,**kwargs):
         from .strain import add_strain
         add_strain(self,fs,**kwargs) 
+    def remove_pairing(self):
+        superconductivity.remove_pairing(self)
     def remove_sites(self,store):
         from . import sculpt
         self.geometry = sculpt.remove_sites(self.geometry,store)
@@ -141,6 +143,7 @@ class Hamiltonian():
       self.hopping_dict = {} # hopping dictonary
       self.has_hopping_dict = False # has hopping dictonary
       self.non_hermitian = False # non hermitian Hamiltonian
+      self.os_gen = None # occupied states generator, for topology
       if not geometry is None:
   # dimensionality of the system
         self.dimensionality = geometry.dimensionality 
